@@ -1,4 +1,4 @@
-#!eusr/bin/perl
+#!/usr/bin/perl
 
 use strict;
 use warnings;
@@ -12,12 +12,14 @@ my $host     = 'host';
 my $username = 'root';
 my $password = 'password';
 my $debug    = undef;
+my $realm    = 'pve'; # 'pve' or 'pam'
 
 GetOptions (
     'host=s'     => \$host,
     'username=s' => \$username,
     'password=s' => \$password,
     'debug'      => \$debug,
+    'realm'      => \$realm,
 );
 
 my $pve = Net::Proxmox::VE->new(
@@ -25,6 +27,7 @@ my $pve = Net::Proxmox::VE->new(
     username => $username,
     password => $password,
     debug    => $debug,
+    realm    => $realm,
 );
 
 die "login failed\n"         unless $pve->login;
